<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/core/ui/about.cpp" line="34"/>
        <source>using Qt </source>
        <translation>usando Qt </translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="41"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="42"/>
        <source>Thanks</source>
        <translation>Agradecimientos</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="102"/>
        <source>It is a light and powerful application, written in Qt.</source>
        <translation>Es una aplicación ligera y potente, escrita usando Qt.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="105"/>
        <source>Website</source>
        <translation>Sitio web</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="109"/>
        <source>Licensed under the </source>
        <translation>Licenciado bajo la </translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="43"/>
        <source>Help us</source>
        <translation>Ayúdenos</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="113"/>
        <source>Copyright &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</source>
        <translation>Copyright &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="123"/>
        <source>What you can do?</source>
        <translation>¿Qué puede hacer usted?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="100"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>es una aplicación multiplataforma para hacer rápidamente capturas de pantalla del escritorio.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="120"/>
        <source>You can join us and help us if you want. This is an invitation if you like this application.</source>
        <translation>Puede unirse a nosotros y ayudarnos si quiere. Es una invitación si le gusta esta aplicación.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="126"/>
        <source>Translate ScreenGrab to other languages</source>
        <translation>Traducir ScreenGrab a otros idiomas</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="127"/>
        <source>Make suggestions for next releases</source>
        <translation>Hacer sugerencias para próximas versiones</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="128"/>
        <source>Report bugs and issues</source>
        <translation>Informar de fallos y otras cuestiones</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="131"/>
        <source>Bug tracker</source>
        <translation>Seguimiento de errores</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="141"/>
        <source>Translate:</source>
        <translation>Traducción:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="143"/>
        <source> Brazilian Portuguese translation</source>
        <translation> traducción al portugués de Brasil</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="144"/>
        <source>Marcio Moraes</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="146"/>
        <source> Ukrainian translation</source>
        <translation> traducción al ucraniano</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="147"/>
        <source>Gennadi Motsyo</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="149"/>
        <source> Spanish translation</source>
        <translation> traducción al español</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="150"/>
        <source>Burjans L García D</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="152"/>
        <source> Italian translation</source>
        <translation> traducción al italiano</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="156"/>
        <source>Testing:</source>
        <translation>Pruebas:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="158"/>
        <source>Dual monitor support and other in Linux</source>
        <translation>Soporte para monitor doble y otros en Linux</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="159"/>
        <source>Dual monitor support in Linux</source>
        <translation>Soporte para monitor doble en Linux</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="160"/>
        <source>win32-build [Windows XP and 7]</source>
        <translation>win32-build [Windows XP y 7]</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="161"/>
        <source>old win32-build [Windows Vista]</source>
        <translation>antiguo win32-build [Windows Vista]</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="162"/>
        <source>win32-build [Windows 7]</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="300"/>
        <source>Select directory</source>
        <translation>Seleccione el directorio</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="211"/>
        <location filename="../src/core/ui/configwidget.cpp" line="312"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="210"/>
        <source>Directory %1 does not exist. Do you want to create it?</source>
        <translation>El directorio %1 no existe. ¿Desea crearlo?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="311"/>
        <source>Do you want to reset the settings to the defaults?</source>
        <translation>¿Quiere reiniciar la configuración a la predefinida?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="369"/>
        <source>Example: </source>
        <translation>Ejemplo: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="425"/>
        <source>This key is already used in your system! Please select another.</source>
        <translation>¡La tecla ya está siendo usada por el sistema! Seleccione otra.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="431"/>
        <source>This key is already used in ScreenGrab! Please select another.</source>
        <translation>¡La tecla ya está siendo usada en ScreenGrab! Seleccione otra.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="449"/>
        <source>This key is not supported on your system!</source>
        <translation>¡La tecla no está permitida en su sistema!</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="484"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
</context>
<context>
    <name>Core</name>
    <message>
        <location filename="../src/core/core.cpp" line="422"/>
        <source>Saved</source>
        <translation>Guardado</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="444"/>
        <source>Name of saved file is copied to the clipboard</source>
        <translation>El nombre del archivo guardado se copia al portapapeles</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="472"/>
        <source>Copied</source>
        <translation>Copiado</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="422"/>
        <source>Saved to </source>
        <translation>Guardado en </translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="63"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>es una aplicación multiplataforma para hacer rápidamente capturas de pantalla del escritorio.</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="67"/>
        <source>Take a fullscreen screenshot</source>
        <translation>Hacer una captura de la pantalla completa</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="71"/>
        <source>Take a screenshot of the active window</source>
        <translation>Hacer una captura de pantalla de la ventana activa</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="75"/>
        <source>Take a screenshot of a selection of the screen</source>
        <translation>Hacer una captura de pantalla de un área de la pantalla</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="79"/>
        <source>Run the application with a hidden main window</source>
        <translation>Ejecutar la aplicación con la ventana principal oculta</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="450"/>
        <source>Path to saved file is copied to the clipboard</source>
        <translation>La ruta al archivo guardado se copia al portapapeles</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="472"/>
        <source>Screenshot is copied to clipboard</source>
        <translation>La captura de pantalla se copia al portapapeles</translation>
    </message>
</context>
<context>
    <name>DialogUploader</name>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="14"/>
        <source>Upload to internet</source>
        <translation>Subir a internet</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="22"/>
        <source>Upload to</source>
        <translation>Subir a</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="76"/>
        <source>Direct link:</source>
        <translation>Enlace directo:</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="98"/>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="189"/>
        <source>Open this link in the default web-browser</source>
        <translation>Abrir el enlace en el navegador por defecto</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="101"/>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="192"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="114"/>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="155"/>
        <source>Copy this link to the clipboard</source>
        <translation>Copiar el enlace al portapapeles</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="117"/>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="158"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="128"/>
        <source>Extended preformed html or bb codes:</source>
        <translation>Códigos html o bb preformados extendidos:</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="167"/>
        <source>Link to delete image:</source>
        <translation>Enlace para borrar la imagen:</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="300"/>
        <source>Upload</source>
        <translation>Subir</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="313"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="199"/>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="214"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="68"/>
        <source>Uploaded </source>
        <translation>Subido </translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="58"/>
        <source>Size: </source>
        <translation>Tamaño: </translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="58"/>
        <source> pixel</source>
        <translation> píxel</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="71"/>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="212"/>
        <source>Ready to upload</source>
        <translation>Listo para subir</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="108"/>
        <source>Upload processing... Please wait</source>
        <translation>Subida en proceso... Por favor, espere</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="160"/>
        <source>Receiving a response from the server</source>
        <translation>Recibiendo respuesta desde el servidor</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="177"/>
        <source>Upload completed</source>
        <translation>Subida completada</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="206"/>
        <source>Error uploading screenshot</source>
        <translation>Error al subir la captura de pantalla</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="207"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="244"/>
        <source>Open this link in your default web-browser, it may directly delete your uploaded image, without any warnings.</source>
        <translation>Abrir el enlace en el navegador por defecto; puede borrar directamente la imagen subida, sin ningún aviso.</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="245"/>
        <source>Are you sure you want to continue?</source>
        <translation>¿Seguro que quiere continuar?</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="365"/>
        <source>Screenshot </source>
        <translation>Captura de pantalla </translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="70"/>
        <source>Quit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="65"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="64"/>
        <source>New</source>
        <translation>Nuevo</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="66"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="369"/>
        <source>Double click to open screenshot in external default image viewer</source>
        <translation>Haga doble clic para abrir la captura de pantalla en el visor de imágenes externo por defecto</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="378"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="509"/>
        <source>Hide</source>
        <translation>Ocultar</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="69"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="67"/>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="157"/>
        <source>None</source>
        <translation>Ninguna</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="516"/>
        <source>Show</source>
        <translation>Mostrar</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="569"/>
        <source>%1 Files</source>
        <translation>%1 archivos</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="591"/>
        <source>Save As...</source>
        <translation>Guardar como...</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="14"/>
        <source>ScreenGrab</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="79"/>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="89"/>
        <source>Type of screenshot</source>
        <translation>Tipo de captura de pantalla</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="96"/>
        <source>Full screen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="101"/>
        <source>Window</source>
        <translation>Ventana</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="106"/>
        <source>Screen area</source>
        <translation>Área de la pantalla</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="111"/>
        <source>Last selected area</source>
        <translation>Última área seleccionada</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="141"/>
        <source>Delay:</source>
        <translation>Demora:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="203"/>
        <source>Zoom area around mouse</source>
        <translation>Ampliar el área alrededor del ratón</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="210"/>
        <source>No window decoration</source>
        <translation>Sin decoración de ventana</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="217"/>
        <source>Include mouse pointer</source>
        <translation>Incluir el puntero del ratón</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="246"/>
        <source>toolBar</source>
        <translation>Barra de herramientas</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="154"/>
        <source>Delay in seconds before taking screenshot</source>
        <translation>Demora en segundos antes hacer la captura de pantalla</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="160"/>
        <source> sec</source>
        <translation> s</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="68"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="92"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
</context>
<context>
    <name>ModuleUploader</name>
    <message>
        <location filename="../src/modules/uploader/moduleuploader.cpp" line="41"/>
        <source>Upload the screenshot to the default image host</source>
        <translation>Subir la captura de pantalla al sitio para imágenes por defecto</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/moduleuploader.cpp" line="48"/>
        <source>Uploading</source>
        <translation>Subiendo</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/core/regionselect.cpp" line="160"/>
        <source>Use your mouse to draw a rectangle to screenshot or exit pressing
any key or using the right or middle mouse buttons.</source>
        <translation>Use el ratón para dibujar el rectángulo a capturar o salga pulsando
cualquier tecla o los botones derecho o central del ratón.</translation>
    </message>
    <message>
        <location filename="../src/core/regionselect.cpp" line="192"/>
        <source>%1 x %2 pixels </source>
        <translation>%1 x %2 píxeles </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/modules/uploader/moduleuploader.cpp" line="103"/>
        <source>Upload</source>
        <translation>Subir</translation>
    </message>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="35"/>
        <source>External edit</source>
        <translation>Edición externa</translation>
    </message>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="46"/>
        <source>Edit in...</source>
        <translation>Editar en...</translation>
    </message>
</context>
<context>
    <name>Uploader</name>
    <message>
        <location filename="../src/modules/uploader/uploader.cpp" line="225"/>
        <source>Direct link</source>
        <translation>Enlace directo</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/uploader.cpp" line="228"/>
        <source>HTML code</source>
        <translation>Código HTML</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/uploader.cpp" line="231"/>
        <source>BB code</source>
        <translation>Código BB</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/uploader.cpp" line="234"/>
        <source>HTML code with thumb image</source>
        <translation>Código HTML con miniatura de imagen</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/uploader.cpp" line="237"/>
        <source>BB code with thumb image</source>
        <translation>Código BB con miniatura de imagen</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/uploader.cpp" line="240"/>
        <source>URl to delete image</source>
        <translation>URI para borrar la imagen</translation>
    </message>
</context>
<context>
    <name>UploaderConfigWidget</name>
    <message>
        <location filename="../src/modules/uploader/uploaderconfigwidget.ui" line="24"/>
        <source>Common settings</source>
        <translation>Configuración general</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/uploaderconfigwidget.ui" line="32"/>
        <source>Default image host</source>
        <translation>Sitio de imágenes por defecto</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/uploaderconfigwidget.ui" line="44"/>
        <source>Always copy the link to the clipboard</source>
        <translation>Copiar siempre el enlace al portapapeles</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/uploaderconfigwidget.ui" line="65"/>
        <source>Hosts settings</source>
        <translation>Configuración de los servidores</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/uploaderconfigwidget.ui" line="73"/>
        <source>Settings for: </source>
        <translation>Configuración para: </translation>
    </message>
</context>
<context>
    <name>UploaderConfigWidget_ImgUr</name>
    <message>
        <location filename="../src/modules/uploader/imgur/uploaderconfigwidget_imgur.ui" line="20"/>
        <source>Configuration for imgur.com upload</source>
        <translation>Configuración para subir a imgur.com</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/imgur/uploaderconfigwidget_imgur.ui" line="43"/>
        <source>No settings available right now</source>
        <translation>No hay ajustes disponibles de momento</translation>
    </message>
</context>
<context>
    <name>Uploader_ImgUr_Widget</name>
    <message>
        <location filename="../src/modules/uploader/imgur/uploader_imgur_widget.ui" line="20"/>
        <source>Upload to Imgur</source>
        <translation>Subir a Imgur</translation>
    </message>
</context>
<context>
    <name>aboutWidget</name>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="128"/>
        <source>About Qt</source>
        <translation>Acerca de Qt</translation>
    </message>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="154"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
</context>
<context>
    <name>configwidget</name>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="26"/>
        <location filename="../src/core/ui/configwidget.ui" line="627"/>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="192"/>
        <source>Default saving image format</source>
        <translation>Formato por defecto al guardar imágenes</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="316"/>
        <source>Inserting current date time into saved filename</source>
        <translation>Inserta la fecha y hora actuales en el nombre de archivo guardado</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="319"/>
        <source>Insert current date and time in file name</source>
        <translation>Insertar la fecha y hora actuales en el nombre de archivo</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="366"/>
        <source>Autosave screenshot</source>
        <translation>Guardar automáticamente la captura de pantalla</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="378"/>
        <source>Save first screenshot</source>
        <translation>Guardar la primera captura de pantalla</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="245"/>
        <source>Image quality</source>
        <translation>Calidad de la imagen</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="251"/>
        <source>Image quality (1 - small file, 100 - high quality)</source>
        <translation>Calidad de imagen (1 - archivo pequeño, 100 - alta calidad)</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="387"/>
        <source>Allow run multiplies copy of ScreenGrab</source>
        <translation>Permitir múltiples instancias de ScreenGrab</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="400"/>
        <source>Enable external viewer</source>
        <translation>Habilitar el visor externo</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="407"/>
        <source>Fit to edges only inside selected screen area</source>
        <translation>Ajustar a los bordes solo en el área de pantalla seleccionada</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="410"/>
        <source>Fit to edges inside selected area</source>
        <translation>Ajustar a los bordes en el área seleccionada</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="448"/>
        <source>Show ScreenGrab in the system tray</source>
        <translation>Mostrar ScreenGrab en la bandeja del sistema</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="533"/>
        <source>Minimize to tray on click close button</source>
        <translation>Minimizar a la bandeja al hacer clic en el botón de cierre</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="536"/>
        <source>Minimize to tray when closing</source>
        <translation>Minimizar a la bandeja al cerrar</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="575"/>
        <source>Action</source>
        <translation>Acción</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="585"/>
        <source>Global shortcuts</source>
        <translation>Atajos globales</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="597"/>
        <source>Active window</source>
        <translation>Ventana activa</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="602"/>
        <source>Area select</source>
        <translation>Selección del area</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="608"/>
        <source>Local shortcuts</source>
        <translation>Atajos locales</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="612"/>
        <source>New screen</source>
        <translation>Nueva pantalla</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="617"/>
        <source>Save screen</source>
        <translation>Grabar la pantalla</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="622"/>
        <source>Copy screen</source>
        <translation>Copiar la pantalla</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="632"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="655"/>
        <source>Not defined</source>
        <translation>No definido</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="77"/>
        <source>Main</source>
        <translation>Principal</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="87"/>
        <source>System tray</source>
        <translation>Bandeja del sistema</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="122"/>
        <source>Path to default selection dir for saving</source>
        <translation>Ruta al directorio seleccionado por defecto para guardar</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="135"/>
        <source>Browse filesystem</source>
        <translation>Explorar el sistema de archivos</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="138"/>
        <source>Browse</source>
        <translation>Explorar</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="168"/>
        <source>Default filename</source>
        <translation>Nombre por defecto</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="179"/>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="211"/>
        <source>Copy file name to the clipboard when saving</source>
        <translation>Copiar el nombre de archivo al portapapeles al guardar</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="225"/>
        <source>Do not copy</source>
        <translation>No copiar</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="230"/>
        <source>Copy file name only</source>
        <translation>Copiar solo el nombre del archivo</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="235"/>
        <source>Copy full file path</source>
        <translation>Copiar la ruta completa del archivo</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="515"/>
        <source> sec</source>
        <translation> s</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="82"/>
        <source>Advanced</source>
        <translation>Avanzado</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="116"/>
        <source>Default save directory</source>
        <translation>Directorio por omisión donde guardar</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="148"/>
        <source>Default file</source>
        <translation>Archivo por omisión</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="161"/>
        <source>Name:</source>
        <translation>Nombre:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="328"/>
        <source>Template: </source>
        <translation>Plantilla: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="353"/>
        <source>Example: </source>
        <translation>Ejemplo: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="363"/>
        <source>Automatically saving screenshots in grabbing process</source>
        <translation>Guarda automaticamente las capturas de pantalla en un proceso de grabacion</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="457"/>
        <source>Tray messages:</source>
        <translation>Mensajes en bandeja:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="470"/>
        <source>Tray messages display mode</source>
        <translation>Modo de presentación de mensajes en bandeja</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="474"/>
        <source>Never</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="479"/>
        <source>Tray mode</source>
        <translation>Modo en bandeja</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="484"/>
        <source>Always</source>
        <translation>Siempre</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="92"/>
        <source>Shortcuts</source>
        <translation>Atajos de teclado</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="390"/>
        <source>Allow multiple instances of ScreenGrab</source>
        <translation>Permitir múltiples instancias de ScreenGrab</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="397"/>
        <source>Open in external viewer on double click</source>
        <translation>Abrir en el visor externo al hacer doble clic</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="580"/>
        <source>Shortcut</source>
        <translation>Atajos</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="592"/>
        <source>Full screen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="637"/>
        <source>Quit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="648"/>
        <source>Selected shortcut:</source>
        <translation>Atajo seleccionado:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="496"/>
        <source>Time of display tray messages</source>
        <translation>Duración de los mensajes de bandeja</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="512"/>
        <source>Time to display tray messages</source>
        <translation>Tiempo hasta mostrar mensajes de bandeja</translation>
    </message>
</context>
</TS>
